==> hermes-5.6.0.33.tar.gz: hermes-5.6.0.33/app/controllers/hermes/api/dmo/users_controller.rb <==
# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
class Hermes::Api::Dmo::UsersController < Hermes::Api::Dmo::ApplicationController
  require Rails.root.join('lib', 'core_extentions', 'parameters', 'handle_sort').to_s

  VALID_OPERATORS = %w[
    $in
    $nin
    $ne
    $gt
    $gte
    $lt
    $lte
    $regex
  ].freeze

  ACCEPTABLE_PARAMS = %w[
   first_name
   last_name
   email
   gender
   phone_number
   auth_roles
   inactive_at
   current_sign_in_at
   last_sign_in_at
  ].freeze

  REGEX_PARAMS = %w[
  ].freeze

  MUTATE_PARAMS = %i[
    first_name
    last_name
    email
    gender
    phone_number
    auth_roles
  ].freeze
        
  def mutate_params
    MUTATE_PARAMS
  end 

  NO_ACL = [
    "superadministrateur",
    "collaborateur offre logement",
    "cre",
    "rdsl",
    "entreprise",
    "bailleur",
  ]

  def current_user_use_acl 
    (NO_ACL & (current_user&.auth_roles || [])).empty?
  end 

  def can_see_entity
    !(current_user_roles & ['Administrator', 'superadministrateur']).empty?
  end 

  def initialize
    super
    @model = User
    @serializer = Hermes::UserSerializer
  end

  def show 
    @instance = 
     if params[:id] == 'me'
        current_user
      elsif params[:id]
        @model.find_by(id: params[:id], **@query_precision)
      end 
      
    return render_json_error(:not_found, :object_not_found) if !@instance
    return render_json_error(:unauthorized, :cannot_see_entities) if @instance.id != current_user.id && !can_see_entity

    render(
      jsonapi: @instance,
      serializer: @serializer,
      **@options
    )
  end 

  def index
    return render_json_error(:unauthorized, :cannot_see_entities) unless can_see_entity

    acceptable_params *ACCEPTABLE_PARAMS
    regex_params *REGEX_PARAMS
    valid_operators *VALID_OPERATORS

    paginate(
      index_aggregation(no_acl: !current_user_use_acl),
      each_serializer: @serializer,
      **@options
    )
  end

  def switch
    @target = User.find_by(id: params[:id])
    @target = User.find_by(main_applicant_id: params[:id]) || Hermes::Applicant.find_by(id: params[:id])&.user unless @target
    return render(json: { success: false, message: 'Utilisateur target non trouvé.' }, status: :not_found) unless @target
    return render nothing: true, status: :not_found unless @user

    if can_switch?
      if targeatable?
        success_switch_response
      else
        render json: {
          success: false,
          message: 'L\'utilisateur target doit être demandeur, bailleur ou entreprise.'
        }, status: :unprocessable_entity
      end
    else
      render json: {
        success: false,
        message: 'Vous n\'avez pas les droits nécessaire pour effectuer cette action.'
      }, status: :unauthorized
    end
  rescue ActionController::ParameterMissing => e
    render_json_error(:not_acceptable, :parameter_missing, { message: e.message })
  end

  private

  def can_switch?
    current_user_roles.include?('superadministrateur') ||
      current_user_roles.include?('collaborateur offre logement') ||
      current_user_roles.include?('cre')
  end

  def targeatable?
    return true if current_user_roles.include?('superadministrateur') || current_user_roles.include?('cre')

    (%w[demandeur bailleur entreprise] & @target.attributes.slice(:roles, :auth_roles).values.flatten.uniq.compact).any?
  end

  def success_switch_response
    token = @target.generate_jwt(true_user_id: @user.id.to_s)
    render json: {
      success: true,
      info: t(:registered),
      email: @target.email,
      login: @target.login,
      jwt_token: token
    }, status: :ok
  end
end

==> hermes-5.7.0.5.tar.gz: hermes-5.7.0.5/app/controllers/hermes/api/dmo/users_controller.rb <==
# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
class Hermes::Api::Dmo::UsersController < Hermes::Api::Dmo::ApplicationController
  require Rails.root.join('lib', 'core_extentions', 'parameters', 'handle_sort').to_s

  VALID_OPERATORS = %w[
    $in
    $nin
    $ne
    $gt
    $gte
    $lt
    $lte
    $regex
  ].freeze

  ACCEPTABLE_PARAMS = %w[
   first_name
   last_name
   email
   gender
   phone_number
   auth_roles
   inactive_at
   current_sign_in_at
   last_sign_in_at
  ].freeze

  REGEX_PARAMS = %w[
  ].freeze

  MUTATE_PARAMS = %i[
    first_name
    last_name
    email
    gender
    phone_number
    auth_roles
  ].freeze
        
  def mutate_params
    MUTATE_PARAMS
  end 

  NO_ACL = [
    "superadministrateur",
    "collaborateur offre logement",
    "cre",
    "rdsl",
    "entreprise",
    "bailleur",
  ]

  def current_user_use_acl 
    (NO_ACL & (current_user&.auth_roles || [])).empty?
  end 

  def can_see_entity
    !(current_user_roles & ['Administrator', 'superadministrateur']).empty?
  end 

  def initialize
    super
    @model = User
    @serializer = Hermes::UserSerializer
  end

  def show 
    @instance = @model.find_by(id: params[:id], **@query_precision) if params[:id]
    return render_json_error(:not_found, :object_not_found) if !@instance
    return render_json_error(:unauthorized, :cannot_see_entities) if @instance.id != @user.id && !can_see_entity

    render(
      jsonapi: @instance,
      serializer: @serializer,
      **@options
    )
  end 

  def index
    return render_json_error(:unauthorized, :cannot_see_entities) unless can_see_entity

    acceptable_params *ACCEPTABLE_PARAMS
    regex_params *REGEX_PARAMS
    valid_operators *VALID_OPERATORS

    paginate(
      index_aggregation(no_acl: !current_user_use_acl),
      each_serializer: @serializer,
      **@options
    )
  end

  def switch
    @target = User.find_by(id: params[:id])
    @target = User.find_by(main_applicant_id: params[:id]) || Hermes::Applicant.find_by(id: params[:id])&.user unless @target
    return render(json: { success: false, message: 'Utilisateur target non trouvé.' }, status: :not_found) unless @target
    return render nothing: true, status: :not_found unless @user

    if can_switch?
      if targeatable?
        success_switch_response
      else
        render json: {
          success: false,
          message: 'L\'utilisateur target doit être demandeur, bailleur ou entreprise.'
        }, status: :unprocessable_entity
      end
    else
      render json: {
        success: false,
        message: 'Vous n\'avez pas les droits nécessaire pour effectuer cette action.'
      }, status: :unauthorized
    end
  rescue ActionController::ParameterMissing => e
    render_json_error(:not_acceptable, :parameter_missing, { message: e.message })
  end

  private

  def can_switch?
    current_user_roles.include?('superadministrateur') ||
      current_user_roles.include?('collaborateur offre logement') ||
      current_user_roles.include?('cre')
  end

  def targeatable?
    return true if current_user_roles.include?('superadministrateur') || current_user_roles.include?('cre')

    (%w[demandeur bailleur entreprise] & @target.attributes.slice(:roles, :auth_roles).values.flatten.uniq.compact).any?
  end

  def success_switch_response
    token = @target.generate_jwt(true_user_id: @user.id.to_s)
    render json: {
      success: true,
      info: t(:registered),
      email: @target.email,
      login: @target.login,
      jwt_token: token
    }, status: :ok
  end
end
